Change section variables (Variables section) to uppercase. For example,
`${xml_file}` should be `${XML_FILE}`, `&{users}` should be `&{USERS}`,
and `@{test_data}` should be `@{TEST_DATA}`. Make sure all references to the
variable are changed accordingly.
